@@ -167,7 +167,7 @@ class Fit:
     def limits(self):
         """
         Limits to use for the independent variable whenever
-        creating a line-space, plot, etc.
+        creating a linespace, plot, etc.
 
         Defaults to `(-x, x)` where `x` is the largest absolute value
         of the data corresponding to the independent variable.
@@ -176,6 +176,11 @@ class Fit:
         if not hasattr(self, '_limits'):
             xmax = max(abs(self.data.array[0]))
             xmin = min(self.data.array[0])
+
+            x_error = self.data.error[0]
+            if isinstance(x_error, numpy.ndarray):
+                if x_error.ndim == 0: xmax = xmax + x_error
+
             if xmin < 0:
                 self._limits = (-xmax, xmax)
             else:
@@ -230,7 +235,7 @@ class Fit:
         defined in `scipy_data_fitting.Model.symbols`.
 
         If a `prefix` is given (as a number or string), it will affect the scale when
-        creating a line-space, plot, etc.
+        creating a linespace, plot, etc.
 
         When `prefix` is given as a string, it will be converted to a number from [`scipy.constants`][1].
 
